package com.jiuqi.db;

import java.sql.ParameterMetaData;
import java.net.URL;
import java.util.Calendar;
import java.sql.ResultSetMetaData;
import java.sql.Array;
import java.sql.Clob;
import java.sql.Blob;
import java.sql.Ref;
import java.io.Reader;
import java.sql.Timestamp;
import java.sql.Time;
import java.sql.Date;
import java.io.InputStream;
import java.io.ByteArrayInputStream;
import java.math.BigDecimal;
import java.sql.SQLWarning;
import java.sql.SQLException;
import java.sql.Statement;
import java.sql.ResultSet;
import java.sql.Connection;
import java.sql.PreparedStatement;

public class DBPreparedStatement implements PreparedStatement
{
    private PreparedStatement stmt;
    private Connection conn;
    
    public DBPreparedStatement(final PreparedStatement aStmt, final Connection aConn) {
        this.stmt = aStmt;
        this.conn = aConn;
        DBTrace.createConnection(this);
    }
    
    public ResultSet executeQuery(final String string) throws SQLException {
        final ResultSet rs = this.stmt.executeQuery(string);
        return new DBResultSet(this, rs);
    }
    
    public int executeUpdate(final String string) throws SQLException {
        return this.stmt.executeUpdate(string);
    }
    
    public void close() throws SQLException {
        this.stmt.close();
        DBTrace.closeConnection(this);
    }
    
    public int getMaxFieldSize() throws SQLException {
        return this.stmt.getMaxFieldSize();
    }
    
    public void setMaxFieldSize(final int int0) throws SQLException {
        this.stmt.setMaxFieldSize(int0);
    }
    
    public int getMaxRows() throws SQLException {
        return this.stmt.getMaxRows();
    }
    
    public void setMaxRows(final int int0) throws SQLException {
        this.stmt.setMaxRows(int0);
    }
    
    public void setEscapeProcessing(final boolean boolean0) throws SQLException {
        this.stmt.setEscapeProcessing(boolean0);
    }
    
    public int getQueryTimeout() throws SQLException {
        return this.stmt.getQueryTimeout();
    }
    
    public void setQueryTimeout(final int int0) throws SQLException {
        this.stmt.setQueryTimeout(int0);
    }
    
    public void cancel() throws SQLException {
        this.stmt.cancel();
    }
    
    public SQLWarning getWarnings() throws SQLException {
        return this.stmt.getWarnings();
    }
    
    public void clearWarnings() throws SQLException {
        this.stmt.clearWarnings();
    }
    
    public void setCursorName(final String string) throws SQLException {
        this.stmt.setCursorName(string);
    }
    
    public boolean execute(final String string) throws SQLException {
        return this.stmt.execute(string);
    }
    
    public ResultSet getResultSet() throws SQLException {
        return this.stmt.getResultSet();
    }
    
    public int getUpdateCount() throws SQLException {
        return this.stmt.getUpdateCount();
    }
    
    public boolean getMoreResults() throws SQLException {
        return this.stmt.getMoreResults();
    }
    
    public void setFetchDirection(final int int0) throws SQLException {
        this.stmt.setFetchDirection(int0);
    }
    
    public int getFetchDirection() throws SQLException {
        return this.stmt.getFetchDirection();
    }
    
    public void setFetchSize(final int int0) throws SQLException {
        this.stmt.setFetchSize(int0);
    }
    
    public int getFetchSize() throws SQLException {
        return this.stmt.getFetchSize();
    }
    
    public int getResultSetConcurrency() throws SQLException {
        return this.stmt.getResultSetConcurrency();
    }
    
    public int getResultSetType() throws SQLException {
        return this.stmt.getResultSetType();
    }
    
    public void addBatch(final String string) throws SQLException {
        this.stmt.addBatch(string);
    }
    
    public void clearBatch() throws SQLException {
        this.stmt.clearBatch();
    }
    
    public int[] executeBatch() throws SQLException {
        return this.stmt.executeBatch();
    }
    
    public Connection getConnection() throws SQLException {
        return this.conn;
    }
    
    public ResultSet executeQuery() throws SQLException {
        final ResultSet rs = this.stmt.executeQuery();
        return new DBResultSet(this, rs);
    }
    
    public int executeUpdate() throws SQLException {
        return this.stmt.executeUpdate();
    }
    
    public void setNull(final int int0, final int int1) throws SQLException {
        this.stmt.setNull(int0, int1);
    }
    
    public void setBoolean(final int int0, final boolean boolean1) throws SQLException {
        this.stmt.setBoolean(int0, boolean1);
    }
    
    public void setByte(final int int0, final byte byte1) throws SQLException {
        this.stmt.setByte(int0, byte1);
    }
    
    public void setShort(final int int0, final short short1) throws SQLException {
        this.stmt.setShort(int0, short1);
    }
    
    public void setInt(final int int0, final int int1) throws SQLException {
        this.stmt.setInt(int0, int1);
    }
    
    public void setLong(final int int0, final long long1) throws SQLException {
        this.stmt.setLong(int0, long1);
    }
    
    public void setFloat(final int int0, final float float1) throws SQLException {
        this.stmt.setFloat(int0, float1);
    }
    
    public void setDouble(final int int0, final double double1) throws SQLException {
        this.stmt.setDouble(int0, double1);
    }
    
    public void setBigDecimal(final int int0, final BigDecimal bigDecimal) throws SQLException {
        this.stmt.setBigDecimal(int0, bigDecimal);
    }
    
    public void setString(final int int0, final String string) throws SQLException {
        this.stmt.setString(int0, string);
    }
    
    public void setBytes(final int int0, final byte[] byteArray) throws SQLException {
        final byte[] bytes = (byteArray == null) ? new byte[0] : byteArray;
        try {
            final InputStream stream = new ByteArrayInputStream(bytes);
            try {
                this.stmt.setBinaryStream(int0, stream, stream.available());
            }
            finally {
                stream.close();
            }
            stream.close();
        }
        catch (final Exception ex) {
            throw new SQLException("写入流失败" + ex.getMessage());
        }
    }
    
    public void setDate(final int int0, final Date date) throws SQLException {
        this.stmt.setDate(int0, date);
    }
    
    public void setTime(final int int0, final Time time) throws SQLException {
        this.stmt.setTime(int0, time);
    }
    
    public void setTimestamp(final int int0, final Timestamp timestamp) throws SQLException {
        this.stmt.setTimestamp(int0, timestamp);
    }
    
    public void setAsciiStream(final int int0, final InputStream inputStream, final int int2) throws SQLException {
        this.stmt.setAsciiStream(int0, inputStream, int2);
    }
    
    @Deprecated
    public void setUnicodeStream(final int int0, final InputStream inputStream, final int int2) throws SQLException {
        this.stmt.setUnicodeStream(int0, inputStream, int2);
    }
    
    public void setBinaryStream(final int int0, final InputStream inputStream, final int int2) throws SQLException {
        this.stmt.setBinaryStream(int0, inputStream, int2);
    }
    
    public void clearParameters() throws SQLException {
        this.stmt.clearParameters();
    }
    
    public void setObject(final int int0, final Object object, final int int2, final int int3) throws SQLException {
        this.stmt.setObject(int0, object, int2, int3);
    }
    
    public void setObject(final int int0, final Object object, final int int2) throws SQLException {
        this.stmt.setObject(int0, object, int2);
    }
    
    public void setObject(final int int0, final Object object) throws SQLException {
        if (object != null && object instanceof byte[]) {
            this.setBytes(int0, (byte[])object);
        }
        else {
            this.stmt.setObject(int0, object);
        }
    }
    
    public boolean execute() throws SQLException {
        return this.stmt.execute();
    }
    
    public void addBatch() throws SQLException {
        this.stmt.addBatch();
    }
    
    public void setCharacterStream(final int int0, final Reader reader, final int int2) throws SQLException {
        this.stmt.setCharacterStream(int0, reader, int2);
    }
    
    public void setRef(final int int0, final Ref ref) throws SQLException {
        this.stmt.setRef(int0, ref);
    }
    
    public void setBlob(final int int0, final Blob blob) throws SQLException {
        this.stmt.setBlob(int0, blob);
    }
    
    public void setClob(final int int0, final Clob clob) throws SQLException {
        this.stmt.setClob(int0, clob);
    }
    
    public void setArray(final int int0, final Array array) throws SQLException {
        this.stmt.setArray(int0, array);
    }
    
    public ResultSetMetaData getMetaData() throws SQLException {
        return this.stmt.getMetaData();
    }
    
    public void setDate(final int int0, final Date date, final Calendar calendar) throws SQLException {
        this.stmt.setDate(int0, date, calendar);
    }
    
    public void setTime(final int int0, final Time time, final Calendar calendar) throws SQLException {
        this.stmt.setTime(int0, time, calendar);
    }
    
    public void setTimestamp(final int int0, final Timestamp timestamp, final Calendar calendar) throws SQLException {
        this.stmt.setTimestamp(int0, timestamp, calendar);
    }
    
    public void setNull(final int int0, final int int1, final String string) throws SQLException {
        this.stmt.setNull(int0, int1, string);
    }
    
    public void setURL(final int parameterIndex, final URL x) throws SQLException {
        this.stmt.setURL(parameterIndex, x);
    }
    
    public boolean getMoreResults(final int int0) throws SQLException {
        return this.stmt.getMoreResults(int0);
    }
    
    public ResultSet getGeneratedKeys() throws SQLException {
        return this.stmt.getGeneratedKeys();
    }
    
    public int executeUpdate(final String sql, final int autoGeneratedKeys) throws SQLException {
        return this.stmt.executeUpdate(sql, autoGeneratedKeys);
    }
    
    public int executeUpdate(final String sql, final int[] columnIndexes) throws SQLException {
        return this.stmt.executeUpdate(sql, columnIndexes);
    }
    
    public int executeUpdate(final String sql, final String[] columnNames) throws SQLException {
        return this.stmt.executeUpdate(sql, columnNames);
    }
    
    public boolean execute(final String sql, final int autoGeneratedKeys) throws SQLException {
        return this.stmt.execute(sql, autoGeneratedKeys);
    }
    
    public boolean execute(final String sql, final int[] columnIndexes) throws SQLException {
        return this.stmt.execute(sql, columnIndexes);
    }
    
    public boolean execute(final String sql, final String[] columnNames) throws SQLException {
        return this.stmt.execute(sql, columnNames);
    }
    
    public int getResultSetHoldability() throws SQLException {
        return this.stmt.getResultSetHoldability();
    }
    
    public ParameterMetaData getParameterMetaData() throws SQLException {
        return this.stmt.getParameterMetaData();
    }
}
